@@ -3,6 +3,9 @@ import numpy as np
 import pandas as pd
 from snowflake.sqlalchemy import URL
 from sqlalchemy import create_engine
+import logging
+logger = logging.getLogger('snowflake.connector',)
+logger.setLevel(logging.warning())
 
 
 # !conda install -y -c conda-forge pyarrow
